<div align="center">

<img src="https://github.com/user-attachments/assets/48919e29-2916-4ad9-84d4-6567fcbd6247" width="380" alt="hello">

<br />

`$ pip install aism`

</div>

# 📰 Documents
Documentation for Aism.

**APIs and examples**:
- [Fill](./docs/fill.md)
- [Utilities](./docs/utilities.md)

# 🥐 Cookbooks
Be your own chef.
- [Basic cookbook](./cookbooks/basics.ipynb)

# 🙋 FAQs

1. **Why can't I install it on Linux?**<br />
Linux distributions are not yet supported due to my stupid mind. Contribute to fix my GitHub CI (please).

2. **Why is this written in Rust?**<br />
Frankly, I just wanted to learn and practice Rust, nothing else.

3. **Why this?**<br />
because this
